[java-identity-provider COMMIT] in /trunk: idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/reso...

noreply at shibboleth.net noreply at shibboleth.net
Tue Feb 4 07:22:01 EST 2014


Author: rdw
Date: Tue Feb  4 07:22:01 2014
New Revision: 5312

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=5312&view=rev
Log:
IDP265 Add legacy PrincipalConnector Canonicalizer, PrincipalConnector (suitable for being parsed) and tests.  Rename the interface which represents this to make it obvious that this is Legacy

Added:
    trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/LegacyPrincipalDecoder.java
      - copied, changed from r5303, trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/PrincipalConnectorDefinition.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/PrincipalConnector.java   (with props)
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/PrinicpalConnectorCanonicalizer.java   (with props)
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/package-info.java   (with props)
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/PrincipalConnectorTest.java   (with props)
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/attribute/principalconnector/PrinicpalConnectorCanonicalizerTest.java   (with props)
Modified:
    trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/PrincipalConnectorDefinition.java
    trunk/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/impl/AttributeResolverImpl.java
    trunk/idp-attribute-resolver-impl/src/test/java/net/shibboleth/idp/attribute/resolver/impl/AttributeResolverImplTest.java

Copied: trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/LegacyPrincipalDecoder.java (from r5303, trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/PrincipalConnectorDefinition.java)
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/LegacyPrincipalDecoder.java?p2=trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/LegacyPrincipalDecoder.java&p1=trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/PrincipalConnectorDefinition.java&r1=5303&r2=5312&rev=5312&view=diff
==============================================================================
--- trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/PrincipalConnectorDefinition.java (original)
+++ trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/LegacyPrincipalDecoder.java Tue Feb  4 07:22:01 2014
@@ -31,7 +31,7 @@
  * 
  * @param <ConsumedContext> The type of context which is expected.
  */
-public interface PrincipalConnectorDefinition<ConsumedContext extends BaseContext> {
+public interface LegacyPrincipalDecoder<ConsumedContext extends BaseContext> {
 
     /**
      * Resolve the principal with respect to the provided context. This is expected to strip out the

Modified: trunk/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/impl/AttributeResolverImpl.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/impl/AttributeResolverImpl.java?rev=5312&r1=5311&r2=5312&view=diff
==============================================================================
--- trunk/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/impl/AttributeResolverImpl.java (original)
+++ trunk/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/impl/AttributeResolverImpl.java Tue Feb  4 07:22:01 2014
@@ -32,7 +32,7 @@
 import net.shibboleth.idp.attribute.resolver.AttributeDefinition;
 import net.shibboleth.idp.attribute.resolver.AttributeResolver;
 import net.shibboleth.idp.attribute.resolver.DataConnector;
-import net.shibboleth.idp.attribute.resolver.PrincipalConnectorDefinition;
+import net.shibboleth.idp.attribute.resolver.LegacyPrincipalDecoder;
 import net.shibboleth.idp.attribute.resolver.ResolutionException;
 import net.shibboleth.idp.attribute.resolver.ResolvedAttributeDefinition;
 import net.shibboleth.idp.attribute.resolver.ResolverPlugin;
@@ -69,12 +69,12 @@
  * {@link net.shibboleth.utilities.java.support.resolver.Resolver} which in about summoning up bits of generic data from
  * the configuration (usually the metadata) in response to specific
  * {@link net.shibboleth.utilities.java.support.resolver.Criterion}s. <br>
  * The implementation also implements {@link PrincipalConnectorDefinition} in support of the deprecated
  * &lt;PrincipalConnector&gt;
@@ -69,12 +69,12 @@
  * the configuration (usually the metadata) in response to specific
  * {@link net.shibboleth.utilities.java.support.resolver.Criterion}s. <br>
- * The implementation also implements {@link PrincipalConnectorDefinition} in support of the deprecated
+ * The implementation also implements {@link LegacyPrincipalDecoder} in support of the deprecated
  * &lt;PrincipalConnector&gt;


[... 51 lines stripped ...]


More information about the commits mailing list